@@ -40,7 +40,7 @@ ConfigValueProvider::ConfigValueProvider()
 {
 }
 
-QString ConfigValueProvider::fixedName() const
+QString ConfigValueProvider::fixedName(const bool isGsettingsFormat) const
 {
     static const QFont defaultFixed(QStringLiteral("Hack"), 10);
 
@@ -49,10 +49,10 @@ QString ConfigValueProvider::fixedName() const
     static QFont font;
     font.fromString(fixedAsString);
     const QString fontStyle = fontStyleHelper(font);
-    return font.family() + QStringLiteral(", ") + fontStyle + ' ' + QString::number(font.pointSize());
+    return font.family() + (isGsettingsFormat ? " " : QStringLiteral(", ")) + fontStyle + ' ' + QString::number(font.pointSize());
 }
 
-QString ConfigValueProvider::fontName() const
+QString ConfigValueProvider::fontName(const bool isGsettingsFormat) const
 {
     static const QFont defaultFont(QStringLiteral("Noto Sans"), 10);
 
@@ -61,7 +61,7 @@ QString ConfigValueProvider::fontName() const
     static QFont font;
     font.fromString(fontAsString);
     const QString fontStyle = fontStyleHelper(font);
-    return font.family() + QStringLiteral(", ") + fontStyle + ' ' + QString::number(font.pointSize());
+    return font.family() + (isGsettingsFormat ? " " : QStringLiteral(", ")) + fontStyle + ' ' + QString::number(font.pointSize());
 }
 
 QString ConfigValueProvider::fontStyleHelper(const QFont &font) const
